## PKG_ADD: Initovisumesh
logv=ver;
isOct=strcmp(logv(1).Name,'Octave');
if isOct
    pkg load general;
    more off
%    pkg load msh
    warning('off','Octave:fopen-file-in-path') % disable warning for mesh files in path
end
P = strcat(fileparts(mfilename('fullpath')),filesep);
addpath([P,'base']);
addpath([P,'graphics']);
addpath([P,'readMesh']);
addpath([P,'export']);
addpath([P,'CompMatOct']);
addpath([P,'demos']);
v=visuMesh_version();
fprintf('Init of Octave ovisumesh package - version %s\n',v);
disp('---------------------------------------------------------');


